pub struct AvidMDisperseShare<TYPES: NodeType> {
pub view_number: ViewNumber,
pub epoch: Option<EpochNumber>,
pub target_epoch: Option<EpochNumber>,
pub payload_commitment: AvidMCommitment,
pub share: AvidMShare,
pub recipient_key: TYPES::SignatureKey,
pub common: AvidMCommon,
}Expand description
VID share and associated metadata for a single node
Fields
view_number: ViewNumberThe view number for which this VID data is intended
epoch: Option<EpochNumber>The epoch number for which this VID data belongs to
target_epoch: Option<EpochNumber>The epoch number to which the recipient of this VID belongs to
payload_commitment: AvidMCommitmentBlock payload commitment
A storage node’s key and its corresponding VID share
recipient_key: TYPES::SignatureKeya public key of the share recipient
common: AvidMCommonVID common data sent to all storage nodes
Implementations
Sourcepub fn to_proposal(
self,
private_key: &<TYPES::SignatureKey as SignatureKey>::PrivateKey,
) -> Option<Proposal<TYPES, Self>>
pub fn to_proposal( self, private_key: &<TYPES::SignatureKey as SignatureKey>::PrivateKey, ) -> Option<Proposal<TYPES, Self>>
Consume self and return a Proposal
Sourcepub fn payload_byte_len(&self) -> u32
pub fn payload_byte_len(&self) -> u32
Returns the payload length in bytes.
Sourcepub fn is_consistent(&self) -> bool
pub fn is_consistent(&self) -> bool
Check if vid common is consistent with the commitment. For AvidM, ns_commits is inside the share, so there’s no separate consistency check.
Sourcepub fn verify_with_verified_common(&self) -> bool
pub fn verify_with_verified_common(&self) -> bool
Verify share assuming common data is already verified consistent. For AvidM, this is equivalent to the full verify since there’s no separate consistency check (ns_commits is inside the share).